:mod:`~kanon.calendars` --- Historical eras and calendar conversions
====================================================================

.. toctree::
  :maxdepth: 2

.. automodapi:: kanon.calendars
    :inherited-members:
    :include-all-objects:

.. automodapi:: kanon.calendars.calendars
    :inherited-members:
